# THis is simple package to install pattern
## Installation
Install it using pip

pip install New_Project


from pattern import (pyramid,right_angle,left_angle)

# pyramid 
pyramid(5)
# output 
    * 
    * *
    * * *
    * * * *
    * * * * *




# right angle
right_angle(5)
*
**
***
****
*****
# left_angle
left_angle(5)
    *
    **
    ***
    ****